@@ -22,7 +22,7 @@ def TTSnorm(text, punc = False, unknown = True, lower = True, rule = False ):
         Command.append("-lower")
     if rule:
         Command.append("-rule")
-    subprocess.check_call([E], env=myenv, cwd=A)
+    subprocess.check_call(E, env=myenv, cwd=A)
     
     O=A+"/output.txt"
     with open(O,"r") as fr:
